@@ -1,5 +1,6 @@
 #!/usr/bin/python
 # encoding=utf-8
+from loguru import logger
 
 from monitors.page.cutter import VideoCutter
 from monitors.page.classifier.keras import KerasClassifier
@@ -41,7 +42,7 @@ def train(data_home, loop):
         # 轮数
         epochs=int(loop),
         # 保证数据集的分辨率统一性
-        target_size=(600, 800),
+        target_size=(888, 1920),
     )
     cl.train(data_home)
     cl.save_model(model_file, overwrite=True)
@@ -54,6 +55,7 @@ def predict(video_path, model_file):
     :param model_file: model_file = "./keras_model.h5"
     :return:
     """
+    logger.info('------------ Start analyzing video！------------- ')
 
     video = VideoObject(video_path)
     video.load_frames()
@@ -67,7 +69,7 @@ def predict(video_path, model_file):
     cl = KerasClassifier(
         # 在使用时需要保证数据集格式统一（与训练集）
         # 因为 train_model.py 用了 600x800，所以这里设定成一样的
-        target_size=(600, 800),
+        target_size=(888, 1920),
     )
 
     cl.load_model(model_file)
