@@ -18,7 +18,7 @@ class Settings(object):
     monitor_duration = 1
     host = None
     port = 8806
-    username = None
+    username = 'admin'
     password = None
     database = None
     table = None
