@@ -1,5 +1,6 @@
 #!/usr/bin/python
 # encoding=utf-8
+from loguru import logger
 
 from monitors.page.classifier import SVMClassifier
 from monitors.page.cutter import VideoCutter
@@ -56,6 +57,7 @@ def predict(target_video, model_path):
     :param model_path: './model.pkl'
     :return:
     """
+    logger.info('------------ Start analyzing video！------------- ')
 
     # cut
     # 这里依旧使用了 cut，主要目的还是为了可以比较好的处理变化中的过程
